PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/DRC.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
DRC.hpp
1#ifndef GYM_PCB_DRC_H
2#define GYM_PCB_DRC_H
3
4#include "Py.hpp"
5#include "Geometry.hpp"
6
7class Connection;
8class Pin;
9
10 class DRCViolation
11{
12public:
13 DRCViolation(Point_25, Connection *, Connection *, Pin *);
14 const Point_25& getLocation() const { return mLocation; }
15 Connection *getConnection(uint i) const { return mConnections[i ? 1 : 0]; }
16 PyObject *getPy() const;
17private:
18 Point_25 mLocation;
19 Connection *mConnections[2];
20 Pin *mPin;
21};
22inline DRCViolation::DRCViolation(Point_25 x, Connection *A, Connection *B, Pin *P) : mLocation(x), mPin(P)
23{
24 mConnections[0] = A;
25 mConnections[1] = B;
26}
27
28#endif // GYM_PCB_DRC_H
Connection
Definition Connection.hpp:17
Pin
Definition Pin.hpp:18
Point_25
Definition Geometry.hpp:131